@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2006, Edward Duffy (eduffy@gmail.com)
- * Copyright (C) 2008, Nokia
+ * Copyright (C) 2006, Edward Duffy <eduffy@gmail.com>
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -27,27 +27,28 @@
 #include <libtracker-common/tracker-utils.h>
 
 #include <libtracker-extract/tracker-extract.h>
-
-static const gchar *tags[][2] = {
-	{ "TOTEM_INFO_VIDEO_HEIGHT",            "nfo:height"    },
-	{ "TOTEM_INFO_VIDEO_WIDTH",             "nfo:width"     },
-	{ "TOTEM_INFO_FPS",                     "nfo:frameRate"         },
-	{ "TOTEM_INFO_VIDEO_CODEC",             "nfo:codec"     },
-	{ "TOTEM_INFO_VIDEO_BITRATE",           "nfo:averageBitrate"    },
-	{ "TOTEM_INFO_TITLE",                   "nie:title"     },
-	{ "TOTEM_INFO_ARTIST",                  "nco:creator"   },
-	{ "TOTEM_INFO_ALBUM",                   "nmm:musicAlbum"        },
-	{ "TOTEM_INFO_AUDIO_BITRATE",           "nmm:averageBitrate"    },
-	{ "TOTEM_INFO_AUDIO_SAMPLE_RATE",       "nfo:sampleRate"                },
-	{ "TOTEM_INFO_AUDIO_CODEC",             "nfo:codec"             },
-	{ "TOTEM_INFO_AUDIO_CHANNELS",          "nfo:channels"          },
-	{ NULL,                                         NULL                    }
-};
+#include <libtracker-client/tracker.h>
 
 static void extract_totem (const gchar          *uri,
                            TrackerSparqlBuilder *preupdate,
                            TrackerSparqlBuilder *metadata);
 
+static const gchar *tags[][2] = {
+	{ "TOTEM_INFO_VIDEO_HEIGHT",      "nfo:height"         },
+	{ "TOTEM_INFO_VIDEO_WIDTH",       "nfo:width"          },
+	{ "TOTEM_INFO_FPS",               "nfo:frameRate"      },
+	{ "TOTEM_INFO_VIDEO_CODEC",       "nfo:codec"          },
+	{ "TOTEM_INFO_VIDEO_BITRATE",     "nfo:averageBitrate" },
+	{ "TOTEM_INFO_TITLE",             "nie:title"          },
+	{ "TOTEM_INFO_ARTIST",            "nco:creator"        },
+	{ "TOTEM_INFO_ALBUM",             "nmm:musicAlbum"     },
+	{ "TOTEM_INFO_AUDIO_BITRATE",     "nfo:averageBitrate" },
+	{ "TOTEM_INFO_AUDIO_SAMPLE_RATE", "nfo:sampleRate"     },
+	{ "TOTEM_INFO_AUDIO_CODEC",       "nfo:codec"          },
+	{ "TOTEM_INFO_AUDIO_CHANNELS",    "nfo:channels"       },
+	{ NULL, NULL }
+};
+
 static TrackerExtractData data[] = {
 	{ "audio/*", extract_totem },
 	{ "video/*", extract_totem },
@@ -84,7 +85,7 @@ extract_totem (const gchar          *uri,
 	                                      (GDestroyNotify) g_free,
 	                                      (GDestroyNotify) g_free);
 
-	if (tracker_spawn (argv, 10, &totem, NULL)) {
+	if (tracker_spawn (argv, 10, &totem, NULL, NULL)) {
 		gchar **lines, **line;
 		gchar *artist = NULL, *album = NULL;
 		gchar *artist_uri = NULL, *album_uri = NULL;
